// random stores seed to static variables
// as all threads are working with the same seed, the results
// differ from run to run even when seed is set with srand

#include <stdio.h>
#include <stdlib.h>
#include <pthread.h>

#define NTHREADS 2
#define NSAMPLES 1000000

struct params 
{
    int id;
    double pi;
};

void *MonteCarloPi(void *arg)
{
    double x, y;
    struct params *p = (struct params *)arg;

    long cnt = 0;
    for(int i = 0; i < NSAMPLES; i++)
    {
        x = rand() / (double)RAND_MAX;
        y = rand() / (double)RAND_MAX;        
        if (x*x + y*y < 1.0) 
            cnt++;
    }

    p->pi = 4.0 * cnt / NSAMPLES;
}

int main(void)
{
    pthread_t t[NTHREADS];
    struct params p[NTHREADS];

    srand(3141592);

    for (int i = 0; i < NTHREADS; i++)
    {
        p[i].id = i;
        p[i].pi = 0;
        pthread_create(&t[i], NULL, MonteCarloPi, &p[i]);
    }

    for (int i = 0; i < NTHREADS; i++)
    {
        pthread_join(t[i], NULL);
        printf("Nit %i: Pi: %lf\n", p[i].id, p[i].pi);
    }

    return 0;
}